/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on October 11, 2002, 6:05 PM
 */

package org.xspace.mx;

/**
 * <p>A {@link Unit} represents some multiple of a {@link UnitType}.
 *  That multiple is equivalent to the power by which a {@link UnitType} is raised.</p>
 *
 * <p>For example, a {@link Measurement} of five square meters (5 [m^2]) has a <i>Length {@link Unit}</i>
 * raised to the power of two (2).</p>
 *
 * @author Michel Santos
 * @since 0.1
 */
public interface Unit {
  
  /**
   * A reference to {@link UnitType} that this {@link Unit} is a multiple of.
   *
   * @return A reference to {@link UnitType} that this {@link Unit} is a multiple of.
   */
  public org.xspace.mx.UnitType getType();
  
  /**
   * The power that the {@link UnitType} has been raised to.
   *
   * @return The power that the {@link UnitType} has been raised to.
   */
  public double getPower();

  /**
   * The power that this {@link Unit} should be set to.
   *
   * @param power The power that this {@link Unit} should be set to.
   */
  public void setPower(double power);
}
