/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created in April 2003
 */

package org.xspace.mx.physics.immutable;

/**
 * A Measurement representing a solar day.
 *
 * @author Michel Santos
 * @since 0.5
 */
public class Day extends Time {
  
  /**
   * Creates a Measurement equal to one solar Day
   */
  public Day() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of solar Days
   *
   * @param value The number of Days
   */
  public Day(double value) {
    dims[DIM_TIME].setPower(1);
    
    double scaling = 60 * 60 * 24;
    this.systemValue = scaling * value;
  }

  /**
   * Creates a Measurement that is equivalent to the input
   */
  public Day(org.xspace.mx.Measurement mx) {
    this(mx.getValue(Units.day));
  }
  
  /**
   * An abbreviated description of the units of a solar Day
   *
   * @return The string "day"
   */
  public String getAbbr() {return "day";}

  /**
   * A description of the units of a solar Day
   *
   * @return The string "days"
   */
  public String getDescription() {return "days";}    
}
