/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on April 2003
 */

package org.xspace.mx.physics.immutable;

/**
 * A Measurement representing a foot.
 *
 * @author Michel Santos
 * @since 0.5
 */
public class Foot extends Length {
  
  /**
   * Creates a Measurement equal to one Foot
   */
  public Foot() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of Feet
   *
   * @param value The number of Feet
   */
  public Foot(double value) {
    dims[DIM_LENGTH].setPower(1);
    
    double scaling = 0.3048;
    this.systemValue = scaling * value;
  }

  /**
   * Creates a Measurement that is equivalent to the input
   */
  public Foot(org.xspace.mx.Measurement mx) {
    this(mx.getValue(Units.ft));
  }  
  
  /**
   * An abbreviated description of the units of a Foot
   *
   * @return The string "ft"
   */
  public String getAbbr() {return "ft";}

  /**
   * A description of the units of a Foot
   *
   * @return The string "feet"
   */
  public String getDescription() {return "feet";}
}
