/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on April 2003
 */

package org.xspace.mx.physics.immutable;

/**
 * A Measurement representing a kilogram.
 *
 * @author Michel Santos
 * @since 0.5
 */
public class Kilogram extends Mass {
  
  /**
   * Creates a Measurement equal to one Kilogram
   */
  public Kilogram() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of Kilograms
   *
   * @param value The number of Kilograms
   */
  public Kilogram(double value) {
    dims[DIM_MASS].setPower(1);
    
    double scaling = 1.0;
    this.systemValue = scaling * value;
  }
  
  /**
   * Creates a Measurement that is equivalent to the input
   */
  public Kilogram(org.xspace.mx.Measurement mx) {
    this(mx.getValue(Units.kg));
  }
  
  /**
   * An abbreviated description of the units of a Kilogram
   *
   * @return The string "kg"
   */
  public String getAbbr() {return "kg";}
  
  /**
   * A description of the units of a Kilogram
   *
   * @return The string "kilograms"
   */  
  public String getDescription() {return "kilograms";}
}
