/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on April 2003
 */

package org.xspace.mx.physics.immutable;

/**
 * A Measurement representing a kilometer.
 *
 * @author Michel Santos
 * @since 0.5
 */
public class Kilometer extends Length {
  
  /**
   * Creates a Measurement equal to one Kilometer
   */
  public Kilometer() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of Kilometers
   *
   * @param value The number of Kilometers
   */
  public Kilometer(double value) {
    dims[DIM_LENGTH].setPower(1);
    
    double scaling = 1e3;
    this.systemValue = scaling * value;
  }
  
  /**
   * Creates a Measurement that is equivalent to the input
   */
  public Kilometer(org.xspace.mx.Measurement mx) {
    this(mx.getValue(Units.km));
  }  

  /**
   * An abbreviated description of the units of a Kilometer
   *
   * @return The string "km"
   */
  public String getAbbr() {return "km";}
  
  
  /**
   * A description of the units of a Kilometer
   *
   * @return The string "kilometers"
   */
  public String getDescription() {return "kilometers";}  
}
