/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on April 2003
 */

package org.xspace.mx.physics.immutable;

/**
 * A Measurement representing a meter.
 *
 * @author Michel Santos
 * @since 0.5
 */
public class Meter extends Length {
  
  /**
   * Creates a Measurement equal to one Meter
   */
  public Meter() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of Meters
   *
   * @param value The number of Meters
   */
  public Meter(double value) {
    dims[DIM_LENGTH].setPower(1);
    
    double scaling = 1.0;
    this.systemValue = scaling * value;
  }
  
  /**
   * Creates a Measurement that is equivalent to the input
   */
  public Meter(org.xspace.mx.Measurement mx) {
    this(mx.getValue(Units.m));
  }  
  
  /**
   * An abbreviated description of the units of a Meter
   *
   * @return The string "m"
   */
  public String getAbbr() {return "m";}  
  
  
  /**
   * A description of the units of a Meter
   *
   * @return The string "meters"
   */
  public String getDescription() {return "meters";}

}
