/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on April 2003
 */

package org.xspace.mx.physics.immutable;

/**
 * A Measurement representing a mile.
 *
 * @author Michel Santos
 * @since 0.5
 */
public class Mile extends Length {
  
  /**
   * Creates a Measurement equal to one mile
   */
  public Mile() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of Miles
   *
   * @param value The number of Miles
   */
  public Mile(double value) {
    dims[DIM_LENGTH].setPower(1);
    
    double scaling = 1609.344;
    this.systemValue = scaling * value;
  }
  
  /**
   * Creates a Measurement that is equivalent to the input
   */
  public Mile(org.xspace.mx.Measurement mx) {
    this(mx.getValue(Units.mi));
  }  
  
  /**
   * An abbreviated description of the units of a Mile
   *
   * @return The string "mi"
   */
  public String getAbbr() {return "mi";}  
  
  
  /**
   * A description of the units of a Mile
   *
   * @return The string "miles"
   */
  public String getDescription() {return "miles";}
  
}
