/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on April 2003
 */

package org.xspace.mx.physics.immutable;

/**
 * A Measurement representing an angular revolution.
 *
 * @author Michel Santos
 * @since 0.5
 */
public class Revolution extends Angle {
  
  /**
   * Creates a Measurement equal to one Revolution
   */
  public Revolution() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of Revolutions
   *
   * @param value The number of Revolutions
   */
  public Revolution(double value) {
    dims[DIM_ANGLE].setPower(1);
    
    double scaling = 2.0 * Math.PI;
    this.systemValue = scaling * value;
  }

  /**
   * Creates a Measurement that is equivalent to the input
   */
  public Revolution(org.xspace.mx.Measurement mx) {
    this(mx.getValue(Units.rev));
  }  
  
  /**
   * An abbreviated description of the units of a Revolution
   *
   * @return The string "rev"
   */
  public String getAbbr() {return "rev";}
  
  
  /**
   * A description of the units of a Revolution
   *
   * @return The string "revolutions"
   */
  public String getDescription() {return "revolutions";}}
