/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on October 13, 2002, 5:55 PM
 */

package org.xspace.mx.physics.mutable;

/**
 * A Measurement representing an Astronomical Unit.
 * An Astronomical Unit is an approximate distance between the Earth and the Sun.
 * According to the <a href="http://neo.jpl.nasa.gov/glossary/au.html">Jet Propulsion Laboratory</a>,
 * <b>1 AU = 149,597,870.691 kilometers</b>
 *
 * @author Michel Santos
 * @since 0.5
 */
public class AstronomicalUnit extends BaseUnit {
  
  /**
   * Creates a Measurement equal to one Astronomical Unit
   */
  public AstronomicalUnit() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of Astronomical Units
   *
   * @param value The number of Astronomical Units
   */
  public AstronomicalUnit(double value) {
    dims[DIM_LENGTH].setPower(1);
    
    // double scaling = 149597900000.0;
    double scaling = 149597870691.0; // JPL
    this.systemValue = scaling * value;
  }
  
  /**
   * An abbreviated description of the units of an Astronomical Unit
   *
   * @return The string "AU"
   */
  public String getAbbr() {return "AU";}  

  /**
   * A description of the units of an Astronomical Unit
   *
   * @return The string "Astronomical Units"
   */
  public String getDescription() {return "Astronomical Units";}
}
