/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on December 1, 2002, 9:55 PM
 */

package org.xspace.mx.physics.mutable;

/**
 * A Measurement representing an angular degree.
 *
 * @author Michel Santos
 * @since 0.1
 */
public class Degree extends BaseUnit {
  
  /**
   * Creates a Measurement equal to one Degree
   */
  public Degree() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of Degrees
   *
   * @param value The number of Degrees
   */
  public Degree(double value) {
    dims[DIM_ANGLE].setPower(1);
    
    double scaling = Math.PI / 180.0;
    this.systemValue = scaling * value;
  }

  /**
   * An abbreviated description of the units of a Degree
   *
   * @return The string "deg"
   */
  public String getAbbr() {return "deg";}

  
  /**
   * A description of the units of a Degree
   *
   * @return The string "degrees"
   */  
  public String getDescription() {return "degrees";}
}
