/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on October 13, 2002, 5:02 PM
 */

package org.xspace.mx.physics.mutable;

/**
 * A Measurement representing an inch.
 *
 * @author Michel Santos
 * @since 0.1
 */
public class Inch extends BaseUnit {
  
  /**
   * Creates a Measurement equal to one Inch
   */
  public Inch() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of Inches
   *
   * @param value The number of Inches
   */
  public Inch(double value) {    
    dims[DIM_LENGTH].setPower(1);
    
    double scaling = 0.0254;
    this.systemValue = scaling * value;
  }

  /**
   * An abbreviated description of the units of a Inch
   *
   * @return The string "in"
   */
  public String getAbbr() {return "in";}
  
  
  /**
   * A description of the units of a Inch
   *
   * @return The string "inches"
   */
  public String getDescription() {return "inches";}
}
