/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on October 13, 2002, 5:58 PM
 */

package org.xspace.mx.physics.mutable;

/**
 * A Measurement representing a kilogram.
 *
 * @author Michel Santos
 * @since 0.1
 */
public class Kilogram extends BaseUnit {
  
  /**
   * Creates a Measurement equal to one Kilogram
   */
  public Kilogram() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of Kilograms
   *
   * @param value The number of Kilograms
   */
  public Kilogram(double value) {
    dims[DIM_MASS].setPower(1);
    
    double scaling = 1.0;
    this.systemValue = scaling * value;
  }
  
  /**
   * An abbreviated description of the units of a Kilogram
   *
   * @return The string "kg"
   */
  public String getAbbr() {return "kg";}
  
  /**
   * A description of the units of a Kilogram
   *
   * @return The string "kilograms"
   */  
  public String getDescription() {return "kilograms";}
}
