/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on March 30, 2003, 3:35 PM
 */

package org.xspace.mx.physics.mutable;

/**
 * A Measurement representing a minute.
 *
 * @author Michel Santos
 * @since 0.1
 */
public class Minute extends BaseUnit {
  
  /**
   * Creates a Measurement equal to one Minute
   */
  public Minute() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of Minutes
   *
   * @param value The number of Minutes
   */
  public Minute(double value) {
    dims[DIM_TIME].setPower(1);
    
    double scaling = 60;
    this.systemValue = scaling * value;
  }

  /**
   * An abbreviated description of the units of a Minute
   *
   * @return The string "min"
   */
  public String getAbbr() {return "min";}
  
  /**
   * A description of the units of a Minute
   *
   * @return The string "minutes"
   */  
  public String getDescription() {return "minutes";}
}
