/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on December 1, 2002, 9:52 PM
 */

package org.xspace.mx.physics.mutable;

/**
 * A Measurement representing a radian.
 *
 * @author Michel Santos
 * @since 0.1
 */
public class Radian extends BaseUnit {
  
  /**
   * Creates a Measurement equal to one Radian
   */
  public Radian() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of Radians
   *
   * @param value The number of Radians
   */
  public Radian(double value) {
    dims[DIM_ANGLE].setPower(1);
    
    double scaling = 1.0;
    this.systemValue = scaling * value;
  }

  /**
   * An abbreviated description of the units of a Radian
   *
   * @return The string "rad"
   */
  public String getAbbr() {return "rad";}
  
  
  /**
   * A description of the units of a Radian
   *
   * @return The string "radians"
   */
  public String getDescription() {return "radians";}  
}
