/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created April, 9 2006
 */

package org.xspace.mx.physics.mutable;


/**
 * A Measurement representing a sidereal day
 *
 * @author Michel Santos
 * @since 0.5.5
 */
public class SiderealDay extends BaseUnit {
  
  /**
   * Creates a Measurement equal to one sidereal day
   */
  public SiderealDay() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of sidereal days
   *
   * @param value The number of Days
   */
  public SiderealDay(double value) {
    dims[DIM_TIME].setPower(1);
    
    double scaling = 60 * 60 * 24;
    scaling *= 0.99726956633; // Astronomical Almanac 2001, B6
    this.systemValue = scaling * value;
  }

  private static final SiderealDay SIDEREAL_DAY = new SiderealDay();
  /**
   * Creates a Measurement that is equivalent to the input
   */
  public SiderealDay(org.xspace.mx.Measurement mx) {
    this(mx.getValue(SIDEREAL_DAY));
  }
  
  /**
   * An abbreviated description of the units of a sidereal day
   *
   * @return The string "sday"
   */
  public String getAbbr() {return "sday";}

  /**
   * A description of the units of a sidereal day
   *
   * @return The string "sidereal days"
   */
  public String getDescription() {return "sidereal days";}    
}